Skip to contents

Launches a Shiny app for uploading a CGM data file, selecting the target, subject, timestamp, and feature columns, running run_missing_glucose_imputation(), previewing the imputed data, and downloading the completed data as a CSV file.

Usage

run_app()

Value

Invisibly returns the result of shiny::runApp().

Examples

if (FALSE) { # \dontrun{
# Run the CGMissingDataR Shiny app
run_app()
} # }